==> haskell-yesod-default-1.2.0-494-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-APBAwVhwE7FJBcc6axLDaI
key: yesod-default-1.2.0-APBAwVhwE7FJBcc6axLDaI
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: 287ac5ae2bb9bcd0118c1579b9d6a052
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-APBAwVhwE7FJBcc6axLDaI
depends:
    base-4.12.0.0 yesod-core-1.6.13-aE2fOCSUT8DQYVRrj0QWI
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-495-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-7OAtMpDLRKP1641PfhZntc
key: yesod-default-1.2.0-7OAtMpDLRKP1641PfhZntc
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: a7aa2e95dc6b8479c186b651fabae5f4
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-7OAtMpDLRKP1641PfhZntc
depends:
    base-4.12.0.0 yesod-core-1.6.13-BmqcDSPw08IBqLieabJ8lI
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
